# Managing Fact Sheet Resources (GraphQL)
### On this page
  * [Creating a Resource on a Fact Sheet](https://help.sap.com/docs/leanix/ea/managing-resources-on-fact-sheet#creating-a-resource-on-a-fact-sheet)
  * [Retrieving Fact Sheet Resources](https://help.sap.com/docs/leanix/ea/managing-resources-on-fact-sheet#retrieving-fact-sheet-resources)
  * [Updating a Resource on a Fact Sheet](https://help.sap.com/docs/leanix/ea/managing-resources-on-fact-sheet#updating-a-resource-on-a-fact-sheet)
  * [Deleting a Resource from a Fact Sheet](https://help.sap.com/docs/leanix/ea/managing-resources-on-fact-sheet#deleting-a-resource-from-a-fact-sheet)


Manage fact sheet resources using the GraphQL API.
To store additional information on a fact sheet, you can add the following resources to it: links, files, diagrams, and logos. To learn how to work with resources in the application UI, see [Storing Resources on Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio27592c207a441014b142ca56bfa9decf__storing_resources_on_fact_sheets).
